==> haskell-hls-hlint-plugin-2.1.0.0-101-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-hlint-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-hlint-plugin
version:              2.1.0.0
visibility:           public
id:                   hls-hlint-plugin-2.1.0.0-EqmxewHZVWwF6UF6t1kpBI
key:                  hls-hlint-plugin-2.1.0.0-EqmxewHZVWwF6UF6t1kpBI
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           atreyu.bbb@gmail.com
author:               The Haskell IDE Team
synopsis:             Hlint integration plugin with Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  7bc1c4ac93755279eca5375e653725cb
exposed:              True
exposed-modules:      Ide.Plugin.Hlint
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hls-hlint-plugin-2.1.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hls-hlint-plugin-2.1.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hls-hlint-plugin-2.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-hlint-plugin
hs-libraries:         HShls-hlint-plugin-2.1.0.0-EqmxewHZVWwF6UF6t1kpBI
depends:
    Diff-0.5-yETzKh0qtuDUuvJdOns8X aeson-2.1.2.1-GojnAvr1Jep10WUNi5H1Pi
    apply-refact-0.14.0.0-2C5hnNvmFAq91blNTqQuBV base-4.18.2.1
    binary-0.8.9.1 bytestring-0.11.5.3 containers-0.6.7
    data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz deepseq-1.4.8.1
    directory-1.3.8.5 extra-1.7.16-3o8MjPiNQTlLg74BSenHLy
    filepath-1.4.300.1 ghc-9.6.6 ghc-boot-9.6.6
    ghc-exactprint-1.7.1.0-F0i4FugjRs4FGSGCq308uf
    ghc-lib-parser-ex-9.6.0.2-8X52mS6lbEo3Fw3qe9swLM
    ghcide-2.1.0.0-BlCpiz4ZHvtIqUTiKV6UyX
    hashable-1.4.7.0-DKTv0aQgcZmBEMi2BPTV4Z
    hlint-3.6-AYkwZ12SFWNBJ4GT6RbrGu
    hls-plugin-api-2.1.0.0-IyHsVCiLch7D25xEM5t6Zs
    lens-5.3.3-HAYf6JaG0qX5o8D7xn9NgM
    lsp-2.1.0.0-FDkJ3hOfaOyD0G3xXwdyeX mtl-2.3.1
    refact-0.3.0.2-FJtsqxURVxtCj2G2lOYVeD
    regex-tdfa-1.3.2.5-ATqtlBuPETHJOcVIKuiav2 stm-2.5.1.0
    temporary-1.3-DmygwHaZA8GJCfyTYb6Tkl text-2.0.2
    transformers-0.6.1.0
    unordered-containers-0.2.20.1-50qrTxmoJy9AxZ7OdMnycu

haddock-interfaces:
    /usr/share/doc/haskell-hls-hlint-plugin/html/hls-hlint-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-hlint-plugin/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hls-hlint-plugin-2.1.0.0-104-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-hlint-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-hlint-plugin
version:              2.1.0.0
visibility:           public
id:                   hls-hlint-plugin-2.1.0.0-K5kDOBwFvmP4QWk5Q2Wxrx
key:                  hls-hlint-plugin-2.1.0.0-K5kDOBwFvmP4QWk5Q2Wxrx
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           atreyu.bbb@gmail.com
author:               The Haskell IDE Team
synopsis:             Hlint integration plugin with Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  2d37ab9c05ffd7331ebdaea3d20d97c8
exposed:              True
exposed-modules:      Ide.Plugin.Hlint
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hls-hlint-plugin-2.1.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hls-hlint-plugin-2.1.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hls-hlint-plugin-2.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-hlint-plugin
hs-libraries:         HShls-hlint-plugin-2.1.0.0-K5kDOBwFvmP4QWk5Q2Wxrx
depends:
    Diff-0.5-8gj4s2z6jOl7FPRCGftIez
    aeson-2.1.2.1-CpIoOLI7lIpJkSqSOmDN9y
    apply-refact-0.14.0.0-5w73fjshmyFHf0ylLWm7lu base-4.18.2.1
    binary-0.8.9.1 bytestring-0.11.5.3 containers-0.6.7
    data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz deepseq-1.4.8.1
    directory-1.3.8.5 extra-1.7.16-IkudFHstV64EKMSGT8IWWb
    filepath-1.4.300.1 ghc-9.6.6 ghc-boot-9.6.6
    ghc-exactprint-1.7.1.0-Icc6yarV61YJwCVVP7qqo9
    ghc-lib-parser-ex-9.6.0.2-N3OL9MDf2AGszziPvbcmG
    ghcide-2.1.0.0-FpGXYcNEFHuE24CSyfyNdp
    hashable-1.4.7.0-1GSULm1uRgQBgX6mu6tvYD
    hlint-3.6-8h1VjTRo2IgJGOdCbGdki6
    hls-plugin-api-2.1.0.0-BfiKLSupfw45UdhJj6iHuY
    lens-5.3.3-GI3kNGpcyiIBMdla72MFoB lsp-2.1.0.0-jiZ0SP1Jku9ft66mbKdaK
    mtl-2.3.1 refact-0.3.0.2-FJtsqxURVxtCj2G2lOYVeD
    regex-tdfa-1.3.2.5-EWGvfiHhNcof6jXGuIJ2K stm-2.5.1.0
    temporary-1.3-29RL4tTXoFB72QSCtJnhBC text-2.0.2
    transformers-0.6.1.0
    unordered-containers-0.2.20.1-L0jiELAFLwP1g4FZscm3B5

haddock-interfaces:
    /usr/share/doc/haskell-hls-hlint-plugin/html/hls-hlint-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-hlint-plugin/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
